#!/usr/bin/env node

const crypto = require('crypto')
const fs = require('fs-extra')
const path = require('path')
const {writeFile} = require('@s-ui/helpers/file.js')

const tsConfigTemplate = `\
{
  "extends": "@s-ui/bundler/tsconfig.json",
  "compilerOptions": {
    "rootDir": "./components"
  },
  "include": ["**/*"]
}`

const md5 = str => crypto.createHash('md5').update(str).digest('hex')
const TS_CONFIG_PATH = path.join(process.cwd(), 'tsconfig.json')

const shouldGenerateTSConfig = () => {
  try {
    if (!fs.existsSync(TS_CONFIG_PATH)) return true

    const tsConfigLocal = fs.readFileSync(TS_CONFIG_PATH, {encoding: 'utf8'})
    return md5(tsConfigLocal) !== md5(tsConfigTemplate)
  } catch (err) {
    return true
  }
}

async function main() {
  if (!shouldGenerateTSConfig()) process.exit(0)
  writeFile(TS_CONFIG_PATH, tsConfigTemplate)
}
main()
